#[derive(Keyed)]
{
// Attributes available to this derive:
#[param]
}
This macro generates a parameter struct and an enum of parameter keys.
#[derive(Keyed)]
{
// Attributes available to this derive:
#[param]
}
This macro generates a parameter struct and an enum of parameter keys.